==> open-cluster-management-policy-model-6.7.2-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1beta1/PolicyAutomationSpecBuilder.java <==
package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PolicyAutomationSpecBuilder extends PolicyAutomationSpecFluentImpl<PolicyAutomationSpecBuilder> implements VisitableBuilder<PolicyAutomationSpec,PolicyAutomationSpecBuilder>{
  public PolicyAutomationSpecBuilder() {
    this(false);
  }
  public PolicyAutomationSpecBuilder(Boolean validationEnabled) {
    this(new PolicyAutomationSpec(), validationEnabled);
  }
  public PolicyAutomationSpecBuilder(PolicyAutomationSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public PolicyAutomationSpecBuilder(PolicyAutomationSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PolicyAutomationSpec(), validationEnabled);
  }
  public PolicyAutomationSpecBuilder(PolicyAutomationSpecFluent<?> fluent,PolicyAutomationSpec instance) {
    this(fluent, instance, false);
  }
  public PolicyAutomationSpecBuilder(PolicyAutomationSpecFluent<?> fluent,PolicyAutomationSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAutomationDef(instance.getAutomationDef());
      fluent.withEventHook(instance.getEventHook());
      fluent.withMode(instance.getMode());
      fluent.withPolicyRef(instance.getPolicyRef());
      fluent.withRescanAfter(instance.getRescanAfter());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PolicyAutomationSpecBuilder(PolicyAutomationSpec instance) {
    this(instance,false);
  }
  public PolicyAutomationSpecBuilder(PolicyAutomationSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAutomationDef(instance.getAutomationDef());
      this.withEventHook(instance.getEventHook());
      this.withMode(instance.getMode());
      this.withPolicyRef(instance.getPolicyRef());
      this.withRescanAfter(instance.getRescanAfter());
    }
    this.validationEnabled = validationEnabled; 
  }
  PolicyAutomationSpecFluent<?> fluent;
  Boolean validationEnabled;
  public PolicyAutomationSpec build() {
    PolicyAutomationSpec buildable = new PolicyAutomationSpec(fluent.getAutomationDef(),fluent.getEventHook(),fluent.getMode(),fluent.getPolicyRef(),fluent.getRescanAfter());
    return buildable;
  }
  
}

==> open-cluster-management-policy-model-6.8.0-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1beta1/PolicyAutomationSpecBuilder.java <==
package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PolicyAutomationSpecBuilder extends PolicyAutomationSpecFluent<PolicyAutomationSpecBuilder> implements VisitableBuilder<PolicyAutomationSpec,PolicyAutomationSpecBuilder>{
  public PolicyAutomationSpecBuilder() {
    this(false);
  }
  public PolicyAutomationSpecBuilder(Boolean validationEnabled) {
    this(new PolicyAutomationSpec(), validationEnabled);
  }
  public PolicyAutomationSpecBuilder(PolicyAutomationSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public PolicyAutomationSpecBuilder(PolicyAutomationSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PolicyAutomationSpec(), validationEnabled);
  }
  public PolicyAutomationSpecBuilder(PolicyAutomationSpecFluent<?> fluent,PolicyAutomationSpec instance) {
    this(fluent, instance, false);
  }
  public PolicyAutomationSpecBuilder(PolicyAutomationSpecFluent<?> fluent,PolicyAutomationSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new PolicyAutomationSpec());

    if (instance != null) {
      fluent.withAutomationDef(instance.getAutomationDef());
      fluent.withEventHook(instance.getEventHook());
      fluent.withMode(instance.getMode());
      fluent.withPolicyRef(instance.getPolicyRef());
      fluent.withRescanAfter(instance.getRescanAfter());
      fluent.withAutomationDef(instance.getAutomationDef());
      fluent.withEventHook(instance.getEventHook());
      fluent.withMode(instance.getMode());
      fluent.withPolicyRef(instance.getPolicyRef());
      fluent.withRescanAfter(instance.getRescanAfter());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PolicyAutomationSpecBuilder(PolicyAutomationSpec instance) {
    this(instance,false);
  }
  public PolicyAutomationSpecBuilder(PolicyAutomationSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new PolicyAutomationSpec());

    if (instance != null) {
      this.withAutomationDef(instance.getAutomationDef());
      this.withEventHook(instance.getEventHook());
      this.withMode(instance.getMode());
      this.withPolicyRef(instance.getPolicyRef());
      this.withRescanAfter(instance.getRescanAfter());
      this.withAutomationDef(instance.getAutomationDef());
      this.withEventHook(instance.getEventHook());
      this.withMode(instance.getMode());
      this.withPolicyRef(instance.getPolicyRef());
      this.withRescanAfter(instance.getRescanAfter());
    }
    this.validationEnabled = validationEnabled; 
  }
  PolicyAutomationSpecFluent<?> fluent;
  Boolean validationEnabled;
  public PolicyAutomationSpec build() {
    PolicyAutomationSpec buildable = new PolicyAutomationSpec(fluent.buildAutomationDef(),fluent.getEventHook(),fluent.getMode(),fluent.getPolicyRef(),fluent.getRescanAfter());
    return buildable;
  }
  
}
